require 'yaml'

module Temp

  # A Config object loads the Temp configuration file and provides access to its
  # values for other parts of Temp.
  class Config

    DEFAULT_CONF_FILE = File.expand_path('~/.tempconf')
    DEFAULT_TEMP_DIR = File.expand_path('~/.temp')

    attr_reader :file, :vals, :template_dir
    attr_accessor :template_options

    # Loads a configuration file and sets the configuration variables to the
    # values in the file. If not given a filename, loads the default
    # configuration file. If the configuration file doesn't exist, uses default
    # configuration values. Also accepts template options to make it easier to
    # pass to tempfiles.
    def initialize(file = DEFAULT_CONF_FILE, template_options = {})
      @file = file
      @template_options = template_options

      if File.file? @file
        @vals = YAML::load_file(@file)
      else
        @vals = {
          :template_dir => DEFAULT_TEMP_DIR
        }
      end

      @template_dir = File.expand_path(@vals[:template_dir])
    end

  end

end
