module Temp

  # A Tempfile object acts as a sandbox for the Tempfile DSL.
  class Tempfile

    attr_reader :options, :info, :ignore_files, :erb_files

    # Loads a Tempfile in the specified directory. Options can be passed so that
    # they can be accessed from the Tempfile.
    def initialize(dir, options = {})
      @dir = File.expand_path(dir)
      @file = File.join(@dir, 'Tempfile')
      @options = options
      @info = {}
      @ignore_files = []
      @erb_files = []
      instance_eval File.read(@file) if File.file? @file
    end

    # Gets the object's binding
    def get_binding
      binding
    end

    # Sets the template name
    def name(str)
      info[:name] = str
    end

    # Sets the template description
    def desc(str)
      info[:desc] = str
    end

    # Adds files to the ignore list by expanding the given glob(s)
    def ignore(*files)
      @ignore_files |= files.map do |file|
        Dir.glob(File.join(@dir, file)).map { |f| f.sub(@dir + '/', '') }
      end.flatten
    end

    # Adds files to the ERB list by expanding the given glob(s)
    def use_erb(*files)
      @erb_files |= files.map do |file|
        Dir.glob(File.join(@dir, file)).map { |f| f.sub(@dir + '/', '') }
      end.flatten
    end

  end

end
