require 'fileutils'

module Temp

  # A Template object represents a template and provides information about it.
  class Template

    attr_reader :conf, :tempfile, :path, :filename, :name, :desc, :files

    # Returns an array of all templates in the template directory
    def self.all(conf)
      Dir.entries(conf.template_dir).map do |t|
        unless t == '.' || t == '..'
          Temp::Template.new(t, conf)
        end
      end.compact
    end

    # Loads a template
    def initialize(name, conf)
      @conf = conf
      @path = File.join(@conf.template_dir, name)
      @filename = name
      raise Temp::Exceptions::TemplateNonExistentError unless File.exist? @path

      @tempfile = Temp::Tempfile.new(@path, @conf.template_options)
      @name = @tempfile.info[:name] || name
      @desc = @tempfile.info[:desc] || ''
      @files = Template.find_files(@path) - @tempfile.ignore_files
    end

    # Finds all of the files in a path
    def self.find_files(path)
      path = File.expand_path(path)
      Dir.glob(File.join(path, '**/*')).map { |f| f.sub(path + '/', '') }
    end

  end

end
